@@ -1,15 +1,21 @@
 # This Python file uses the following encoding: utf-8
+import logging
+
 import extract_msg
 
 from PySide6 import QtCore
 from PySide6 import QtWidgets
 from PySide6.QtCore import Signal, SIGNAL, Slot, SLOT
-from PySide6.QtWidgets import QTableWidgetItem
+from PySide6.QtWidgets import QMessageBox, QTableWidgetItem
 
 from . import utils
 from .ui.ui_named_properties_viewer import Ui_NamedPropertiesViewer
 
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
+
 class NamedPIDItem(QTableWidgetItem):
     """
     Little bit of a hack to force the Named PID column to sort properly.
@@ -42,14 +48,18 @@ class NamedPropertiesViewer(QtWidgets.QWidget):
         property, not the data.
         """
         self.ui.tableNamedProperties.setRowCount(len(self.__named))
+        self.ui.tableNamedProperties.setSortingEnabled(False)
         for index, key in enumerate(self.__named):
-            self.ui.tableNamedProperties.setItem(index, 0, QTableWidgetItem(key))
-            self.ui.tableNamedProperties.setItem(index, 1, NamedPIDItem(str(self.__named[key].namedPropertyID)))
+            self.ui.tableNamedProperties.setItem(index, 0, QTableWidgetItem(key[0]))
+            self.ui.tableNamedProperties.setItem(index, 1, QTableWidgetItem(key[1]))
+            self.ui.tableNamedProperties.setItem(index, 2, NamedPIDItem(str(self.__named[key].namedPropertyID)))
+        self.ui.tableNamedProperties.setSortingEnabled(True)
 
     @Slot()
     def msgClosed(self):
         self.ui.comboBoxInstance.clear()
         self.ui.tableNamedProperties.clearContents()
+        self.ui.tableNamedProperties.setRowCount(0)
         self.__msg = None
         self.__named = None
         self.__attachments = None
@@ -68,18 +78,19 @@ class NamedPropertiesViewer(QtWidgets.QWidget):
 
     @Slot(int, int)
     def _cellDoubleClicked(self, row, column):
-        if self.ui.tableNamedProperties.item(row, 2).data(0) == '[Stream]':
+        if self.ui.tableNamedProperties.item(row, 3).data(0) == '[Stream]':
             name = self.ui.tableNamedProperties.item(row, 0).data(0)
-            code = 0x8000 + int(self.ui.tableNamedProperties.item(row, 1).data(0))
+            code = 0x8000 + int(self.ui.tableNamedProperties.item(row, 2).data(0))
             if self.ui.comboBoxInstance.currentText() == 'MSG File':
                 start = ['']
             else:
-                start [f'__attach_version1.0_#{int(self.ui.comboBoxInstance.currentText().split(" ")[1]):08X}', '']
+                start = [f'__attach_version1.0_#{int(self.ui.comboBoxInstance.currentText().split(" ")[1]):08X}', '']
 
             # Now we need to determine the type so we can generate the
             # path to give to the signal.
             for _type in extract_msg.constants.PTYPES:
                 start[-1] = f'__substg1.0_{code:04X}{_type:04X}'
+                logger.info(f'Checking for named property stream at {start}')
                 if self.__msg.exists(start):
                     return self.namedPropertySelected.emit(start)
             else:
@@ -99,17 +110,20 @@ class NamedPropertiesViewer(QtWidgets.QWidget):
                 getData = attachment.namedProperties.get
                 getStream = attachment._getTypedStream
 
+            self.ui.tableNamedProperties.setSortingEnabled(False)
             for index in range(self.ui.tableNamedProperties.rowCount()):
-                key = self.ui.tableNamedProperties.item(index, 0).data(0)
+                key = (self.ui.tableNamedProperties.item(index, 0).data(0),
+                       self.ui.tableNamedProperties.item(index, 1).data(0))
                 # We need to figure out what to display for the data.
                 data = getData(self.__named[key])
                 if isinstance(data, (int, float, bool, None.__class__)):
                     # This helps to shortcut a bunch of properties.
-                    self.ui.tableNamedProperties.setItem(index, 2, QTableWidgetItem(utils.dataToString(data)))
+                    self.ui.tableNamedProperties.setItem(index, 3, QTableWidgetItem(utils.dataToString(data)))
                 elif isinstance(data, (bytes, list, tuple)) or getStream(f'__substg1.0_{self.__named[key].propertyStreamID}')[0]:
-                    self.ui.tableNamedProperties.setItem(index, 2, QTableWidgetItem('[Stream]'))
+                    self.ui.tableNamedProperties.setItem(index, 3, QTableWidgetItem('[Stream]'))
                 else:
-                    self.ui.tableNamedProperties.setItem(index, 2, QTableWidgetItem(utils.dataToString(data)))
+                    self.ui.tableNamedProperties.setItem(index, 3, QTableWidgetItem(utils.dataToString(data)))
+            self.ui.tableNamedProperties.setSortingEnabled(True)
 
 
 
